Lessons API
Removed. The AgentLens Lessons API (
/api/lessons) was removed. Lesson and memory management now lives in Lore, a dedicated cross-agent memory system.Use
lore-sdkor the Lore MCP server to create, list, update, and search lessons. See the Lore Integration migration guide for details.